@@ -3,9 +3,11 @@ Main interface for sso-oidc service type definitions.
 
 Usage::
 
-    from mypy_boto3.sso_oidc.type_defs import CreateTokenResponseTypeDef
+    ```python
+    from mypy_boto3_sso_oidc.type_defs import CreateTokenResponseTypeDef
 
     data: CreateTokenResponseTypeDef = {...}
+    ```
 """
 import sys
 
